==> love-0.9.2-linux-src.tar.gz: love-0.9.2/src/modules/font/freetype/Font.h <==
/**
 * Copyright (c) 2006-2015 LOVE Development Team
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 **/

#ifndef LOVE_FONT_FREETYPE_FONT_H
#define LOVE_FONT_FREETYPE_FONT_H

// LOVE
#include "font/Font.h"

// FreeType2
#ifdef LOVE_MACOSX_USE_FRAMEWORKS
#include <freetype/ft2build.h>
#else
#include <ft2build.h>
#endif
#include FT_FREETYPE_H
#include FT_GLYPH_H

namespace love
{
namespace font
{
namespace freetype
{

class Font : public love::font::Font
{
public:

	Font();

	/**
	 * Destructor.
	 **/
	virtual ~Font();

	// Implements Font
	Rasterizer *newRasterizer(int size);
	Rasterizer *newRasterizer(Data *data, int size);
	Rasterizer *newRasterizer(love::image::ImageData *data, const std::string &text);
	Rasterizer *newRasterizer(love::image::ImageData *data, uint32 *glyphs, int numglyphs);
	GlyphData *newGlyphData(Rasterizer *r, const std::string &glyph);
	GlyphData *newGlyphData(Rasterizer *r, uint32 glyph);

	// Implement Module
	const char *getName() const;

private:

	// FreeType library
	FT_Library library;
}; // Font

} // freetype
} // font
} // love

#endif // LOVE_FONT_FREETYPE_FONT_H

==> love-0.10.2-linux-src.tar.gz: love-0.10.2/src/modules/font/freetype/Font.h <==
/**
 * Copyright (c) 2006-2016 LOVE Development Team
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any damages
 * arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any purpose,
 * including commercial applications, and to alter it and redistribute it
 * freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not
 *    claim that you wrote the original software. If you use this software
 *    in a product, an acknowledgment in the product documentation would be
 *    appreciated but is not required.
 * 2. Altered source versions must be plainly marked as such, and must not be
 *    misrepresented as being the original software.
 * 3. This notice may not be removed or altered from any source distribution.
 **/

#ifndef LOVE_FONT_FREETYPE_FONT_H
#define LOVE_FONT_FREETYPE_FONT_H

// LOVE
#include "font/Font.h"

// FreeType2
#include <ft2build.h>
#include FT_FREETYPE_H
#include FT_GLYPH_H

namespace love
{
namespace font
{
namespace freetype
{

class Font : public love::font::Font
{
public:

	Font();
	virtual ~Font();

	// Implements Font
	Rasterizer *newRasterizer(love::filesystem::FileData *data);
	Rasterizer *newTrueTypeRasterizer(love::Data *data, int size, TrueTypeRasterizer::Hinting hinting);

	// Implement Module
	const char *getName() const;

private:

	// FreeType library
	FT_Library library;

}; // Font

} // freetype
} // font
} // love

#endif // LOVE_FONT_FREETYPE_FONT_H
